@@ -158,6 +158,27 @@ async def gerror(self, given_client: AsyncIOClient = None, {params_fields_str})
     return f"{get_str}\n{gerror_str}"
 
 
+def build_filter_functions_str(node_name: str, conversion_map: T.Dict[str, dict]):
+    field_names = sorted(conversion_map.keys())
+    params_fields_str = ", ".join(
+        [f"{f}: T.Optional[T.Any] = None" for f in field_names]
+    )
+    dict_fields_str = ", ".join([f'"{f}": {f}' for f in field_names])
+    filter_by_str = f"""
+def filter_by(self, {params_fields_str}) -> {node_name}Resolver:
+    return super().filter_by(**{{{dict_fields_str}}})
+    """
+    # now for filter in
+    params_fields_lst_str = ", ".join(
+        [f"{f}: T.Optional[T.List[T.Any]] = None" for f in field_names]
+    )
+    filter_in_str = f"""
+def filter_in(self, {params_fields_lst_str}) -> {node_name}Resolver:
+    return super().filter_in(**{{{dict_fields_str}}})
+    """
+    return f"{filter_by_str}\n{filter_in_str}"
+
+
 def build_update_function_str(node_resolver_name: str, links: T.List[Link]) -> str:
     link_strs: T.List[str] = []
     link_names: T.List[str] = []
@@ -528,6 +549,9 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     resolver_get_functions_str = build_get_functions_str(
         node_name=object_type.node_name, exclusive_field_names=exclusive_fields
     )
+    resolver_filter_functions_str = build_filter_functions_str(
+        node_name=object_type.node_name, conversion_map=node_edgedb_conversion_map
+    )
 
     edge_resolver_val_strs = [
         f"T.Type[{v}]" for v in sorted(set(edge_resolver_map.values()))
@@ -545,6 +569,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
         resolver_properties_str,
         resolver_link_functions_str,
         resolver_get_functions_str,
+        resolver_filter_functions_str,
     ]
     resolver_inner_str = "\n".join(resolver_inner_strs)
     resolver_s = f"class {node_resolver_name}(Resolver[{object_type.node_name}]):\n{indent_lines(resolver_inner_str)}"
