@@ -49,6 +49,7 @@ def model_dict_to_str(
     field_strs: T.List[str] = []
     variables = {}
     for field_name, val in d.items():
+        add_to_variables: bool = True
         type_cast_str = edgedb_conversion_map.get(field_name, {}).get("cast")
         if not type_cast_str:
             # resolvers will come up here so ignore them
@@ -64,9 +65,14 @@ def model_dict_to_str(
             val = json.dumps(jsonable_encoder(val))
         if type(val) is set:
             val = list(val)
-            field_str = f"{field_name} := array_unpack(<array<{type_cast_str}>>${variable_name})"
+            if "array<" not in type_cast_str:
+                field_str = f"{field_name} := array_unpack(<array<{type_cast_str}>>${variable_name})"
+                if len(val) == 0:
+                    add_to_variables = False
+                    field_str = f"{field_name} := {{}}"
         field_strs.append(field_str)
-        variables[variable_name] = val
+        if add_to_variables:
+            variables[variable_name] = val
     if set_links_d:
         for field_name, resolver in set_links_d.items():
             update_operation_str = resolver.update_operation_str
